@@ -19,7 +19,8 @@ def google_trends():
         print('ERR hot terms failed!', str(e))
         return None
 
-NLTK_PUNKT = os.path.join(os.path.dirname(__file__), 'english.pickle')
+CWD = os.path.dirname(__file__)
+NLTK_PUNKT = f"{str(CWD)}/tokenizers/punkt/english.pickle"
 
 STOCKTICKERS = os.path.join(os.path.dirname(__file__), 'stocks.csv')
 SOURCES = Sources
